==========================================
Seed Identity Store documentation contents
==========================================

.. toctree::
    :hidden:

    index

.. toctree::
    :maxdepth: 3

    requirements
    setup
    models
    auth
    apis
    production

Indices, glossary and tables
============================

* :ref:`genindex`
* :ref:`modindex`
* :doc:`glossary`
